@@ -52,34 +52,42 @@ def get_token(username, password, server):
     return token
 
 
-def tonicdns_client(uri, method, token='', data='', keyword='', content=''):
+def tonicdns_client(uri, method, token='', data='', keyword='',
+                    content='', raw_flag=False):
     """TonicDNS API client
 
     Arguments:
 
-        uri:     TonicDNS API URI
-        method:  TonicDNS API request method
-        token:   TonicDNS API authentication token
-        data:    Post data to TonicDNS API
-        keyword: Processing keyword of response
-        content:
+        uri:      TonicDNS API URI
+        method:   TonicDNS API request method
+        token:    TonicDNS API authentication token
+        data:     Post data to TonicDNS API
+        keyword:  Processing keyword of response
+        content:  data exist flag
+        raw_flag: True is return response data, False is pretty printing
     """
     res = request(uri, method, data, token)
     if token:
         if keyword == 'serial':
-            cur_soa, new_soa = response(uri, method,
-                                        res, token, keyword, content)
+            args = {"token": token, "keyword": keyword, "content": content}
+            cur_soa, new_soa = response(uri, method, res, **args)
             return cur_soa, new_soa
 
         else:
             if content is None:
-                response(uri, method, res, token, keyword,
-                         content.get('domain'))
+                args = {"token": token, "keyword": keyword,
+                        "content": content.get('domain')}
+                response(uri, method, res, **args)
             else:
-                response(uri, method, res, token, keyword)
+                # get sub command
+                args = {"token": token, "keyword": keyword,
+                        "raw_flag": raw_flag}
+                data = response(uri, method, res, **args)
+                return data
 
     else:
-        token = response(uri, method, res, token, keyword)
+        args = {"token": token, "keyword": keyword}
+        token = response(uri, method, res, **args)
         return token
 
 
@@ -126,21 +134,22 @@ def request(uri, method, data, token=''):
         exit(1)
 
 
-def response(uri, method, res, token='', keyword='', content=''):
+def response(uri, method, res, token='', keyword='',
+             content='', raw_flag=False):
     """Response of tonicdns_client request
 
     Arguments:
 
-        uri:     TonicDNS API URI
-        method:  TonicDNS API request method
-        res:     Response of against request to TonicDNS API
-        token:   TonicDNS API token
-        keyword: Processing keyword
-        content:
+        uri:      TonicDNS API URI
+        method:   TonicDNS API request method
+        res:      Response of against request to TonicDNS API
+        token:    TonicDNS API token
+        keyword:  Processing keyword
+        content:  JSON data
+        raw_flag: True is return responsed raw data, False is pretty print
     """
     if method == 'GET' or (method == 'PUT' and not token):
         # response body
-
         data = res.read()
         data_utf8 = data.decode('utf-8')
         if token:
@@ -182,7 +191,10 @@ def response(uri, method, res, token='', keyword='', content=''):
 
         else:
             # 'get' subcommand
-            print_formatted(datas)
+            if raw_flag:
+                return datas
+            else:
+                print_formatted(datas)
 
     else:
         # response non JSON data
@@ -200,12 +212,35 @@ def search_record(datas, keyword):
 
     Key target is "name" or "content" or "type". default null.
     Either key and type, or on the other hand.
+
+    When keyword has include camma ",",
+    Separate keyword to name, type, content.
     """
+
+    key_name, key_type, key_content = False, False, False
+
+    if keyword.find(',') > -1:
+        if len(keyword.split(',')) == 3:
+            key_content = keyword.split(',')[2]
+        key_name = keyword.split(',')[0]
+        key_type = keyword.split(',')[1]
+
     result = []
 
     for record in datas['records']:
 
-        if (record['name'].find(keyword) >= 0 or
+        if key_name and key_type:
+            if key_content:
+                if (record['name'].find(key_name) > -1 and
+                    record['type'] == key_type and
+                    record['content'].find(key_content) > -1):
+                    result.append(record)
+            else:
+                if (record['name'].find(key_name) > -1 and
+                    record['type'] == key_type):
+                    result.append(record)
+
+        elif (record['name'].find(keyword) >= 0 or
             record['content'].find(keyword) >= 0 or
             record['type'] == keyword):
             result.append(record)
